package com.usaepaydemo;

import android.content.DialogInterface;
import android.content.Intent;
import android.support.v7.app.AlertDialog;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.AdapterView.OnItemSelectedListener;
import android.widget.Button;
import android.widget.Spinner;


public class MainActivity extends AppCompatActivity {

    /* ** SET SOURCE KEY, PIN, AND HOST ** */
    String sourceKey = "YOUR SOURCE KEY";
    String pin = "YOUR PIN";
    String host = "YOUR HOST";

    private Intent intent;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        // Prepare source key, pin, and host for bundling to different Activities.
        intent = new Intent(MainActivity.this, TransActivity.class);
        intent.putExtra("source_key", sourceKey);
        intent.putExtra("pin", pin);
        intent.putExtra("host", host);

        initConnTypeSpinner();
        initSaleTypeSpinner();
        Button btn_next = (Button) findViewById(R.id.next_btn);
        btn_next.setOnClickListener(new NextBtnListener());
    }

    /**
     * Initializes the 'connection type' spinner.
     */
    private void initConnTypeSpinner() {
        Spinner spinner = (Spinner) findViewById(R.id.conn_type);
        ArrayAdapter<CharSequence> adapter = ArrayAdapter.createFromResource(this,
                R.array.conn_type, android.R.layout.simple_spinner_item);
        adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
        spinner.setAdapter(adapter);
        spinner.setOnItemSelectedListener(spinnerConnTypeSelectedListener);
    }

    /**
     * Listens to which 'connection type' was selected.
     */
    private OnItemSelectedListener spinnerConnTypeSelectedListener = new OnItemSelectedListener() {
        @Override
        public void onItemSelected(AdapterView<?> adapterView, View view, int i, long l) {
            String selected_conn = adapterView.getItemAtPosition(i).toString();
            intent.putExtra("conn_type", selected_conn);
        }

        @Override
        public void onNothingSelected(AdapterView<?> adapterView) {
        }
    };

    /**
     * Initializes the 'sale type' spinner.
     */
    private void initSaleTypeSpinner() {
        Spinner spinner = (Spinner) findViewById(R.id.sale_type);
        ArrayAdapter<CharSequence> adapter = ArrayAdapter.createFromResource(this,
                R.array.sale_type, android.R.layout.simple_spinner_item);
        adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
        spinner.setAdapter(adapter);
        spinner.setOnItemSelectedListener(spinnerSaleTypeSelectedListener);
    }

    /**
     * Listens to which 'sale type' was selected.
     */
    private OnItemSelectedListener spinnerSaleTypeSelectedListener = new OnItemSelectedListener() {
        @Override
        public void onItemSelected(AdapterView<?> adapterView, View view, int i, long l) {
            String selected_sale = adapterView.getItemAtPosition(i).toString();
            intent.putExtra("sale_type", selected_sale);
        }

        @Override
        public void onNothingSelected(AdapterView<?> adapterView) {
        }
    };

    /**
     * Listens for 'Next' button click.
     */
    private class NextBtnListener implements Button.OnClickListener {
        @Override
        public void onClick(View v) {
            startActivity(intent);
        }
    }

	/**
	 * Alert the user that they're exiting the app by pressing 'Back' button while on this Activity.
     */
    @Override
    public void onBackPressed() {
        AlertDialog.Builder builder = new AlertDialog.Builder(MainActivity.this);
        builder.setMessage(getString(R.string.warn_exit))
                .setPositiveButton(R.string.btn_exit, new DialogInterface.OnClickListener() {
                    @Override
                    public void onClick(DialogInterface dialog, int id) {

                        dialog.dismiss();

                        Intent intent = getIntent();
                        intent.addFlags(Intent.FLAG_ACTIVITY_SINGLE_TOP);
                        intent.putExtra("EXIT", true);
                        finish();
                    }
                }).setNegativeButton(R.string.btn_cancel, new DialogInterface.OnClickListener() {
            @Override
            public void onClick(DialogInterface dialog, int id) {

                dialog.dismiss();
            }
        }).create().show();
    }

}
