package com.usaepaydemo;

import android.content.Intent;
import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;

import com.usaepay.middleware.publicclasses.UEMConstants;

import java.text.DecimalFormat;
import java.util.HashMap;

public class TransActivity extends AppCompatActivity {

    private HashMap<String, String> transInfo;
    private String mSelectedConn;
    private String mSelectedSale;
    private EditText et_amount;
    private EditText et_tax;
    private EditText et_tip;
    private EditText et_invoice;
    private EditText et_desc;
    private EditText et_refnum;
    private String mAmount;
    private String mTax;
    private String mTip;
    private String mInvoice;
    private String mDesc;
    private String mRefnum;
    private String sourceKey;
    private String pin;
    private String host;

    @Override
    protected void onCreate(Bundle savedState) {
        super.onCreate(savedState);
        setContentView(R.layout.activity_trans);

		// Get data from MainActivity for use throughout app's lifecycle
        Bundle b = getIntent().getExtras();
        mSelectedConn = b.getString("conn_type");
        mSelectedSale = b.getString("sale_type");
        sourceKey = b.getString("source_key");
        pin       = b.getString("pin");
        host      = b.getString("host");

        // Grab references to UI elements for this Activity.
        // Make sure user doesn't add more than two decimal places in 'Amount', 'Tax', and 'Tip' fields.
        et_amount  = (EditText) findViewById(R.id.amount);
        et_amount.addTextChangedListener(new DecimalInputTextWatcher(et_amount, 2));
        et_tax     = (EditText) findViewById(R.id.tax);
        et_tax.addTextChangedListener(new DecimalInputTextWatcher(et_tax, 2));
        et_tip     = (EditText) findViewById(R.id.tip);
        et_tip.addTextChangedListener(new DecimalInputTextWatcher(et_tip, 2));
        et_invoice = (EditText) findViewById(R.id.invoice);
        et_desc    = (EditText) findViewById(R.id.description);
        et_refnum  = (EditText) findViewById(R.id.refnum);

        // Hide RefNum EditText if user didn't select 'void:release'
        if (mSelectedSale != null) {
            if ( mSelectedSale.equals("void:release") || mSelectedSale.equals("capture") ) {
                et_refnum.setVisibility(View.VISIBLE);
            }
        }

        Button btn_startTrans = (Button) findViewById(R.id.start_trans);
        btn_startTrans.setOnClickListener(new BtnStartTransListener());
    }

    /**
     * BtnStartTransListener
     *
     * SubClass that listens for Start Transaction click.
     * On click, prepares Hash Map with ET fields' values
     * and sends Hash Map to next activity.
     */
    private class BtnStartTransListener implements Button.OnClickListener {
        @Override
        public void onClick(View v) {

            retrieveEditTextValues();

            // Force user to enter an amount.
            if ( mAmount.matches("") ) {
                Toast.makeText(getApplicationContext(), "Enter an amount.",
                        Toast.LENGTH_SHORT).show();
            }
			// If user selected 'void:release' OR 'capture'
			// Force user to enter a reference number.
            else if ( (mSelectedSale.equals("void:release") || mSelectedSale.equals("capture"))
                    && mRefnum.matches("")) {
                Toast.makeText(getApplicationContext(), "Enter a Reference Number.",
                        Toast.LENGTH_SHORT).show();
            }
            // We have the transaction info we need.
            // Bundle it up and start the new activity.
            else {
                mAmount = aggregateTotal(mAmount, mTax, mTip);

                buildTransInfoMap();

                Intent intent = new Intent(TransActivity.this, ProcessingActivity.class);
                Bundle extras = new Bundle();
                extras.putSerializable("TransInfo", transInfo);
                extras.putString("source_key", sourceKey);
                extras.putString("pin", pin);
                extras.putString("host", host);
                intent.putExtras(extras);
                startActivity(intent);
            }
        }
    }

    /**
     * Get EditText values for bundling. Make sure amounts are of correct format.
     */
    private void retrieveEditTextValues() {

        // Check that 'Amount' field is of correct format.
        mAmount = et_amount.getText().toString();
        if (mAmount.matches("")) {
            // Do nothing, let the Toast in onClick Listener tell the user the issue.
        } else if (mAmount.indexOf('.') < 0) {
            // User didn't add decimals.
            mAmount += ".00";
        } else {
            int decimalsAfter = mAmount.substring(mAmount.indexOf(".") + 1).length();
            if (decimalsAfter == 1) {
                // User did add decimal but only to the tens place.
                mAmount += "0";
            }
        }

        // Check that 'Tax' field is of correct format.
        mTax = et_tax.getText().toString();
        if (mTax.matches("")) {
            // User didn't specify a Tip.
            mTax = "0.00";
        } else {
            if (mTax.indexOf('.') < 0) {
                // User didn't add decimal values.
                mTax += ".00";
            } else {
                int decimalsAfter = mTax.substring(mTax.indexOf(".") + 1).length();
                if (decimalsAfter == 1) {
                    // User did add decimal but only to the tens place.
                    mTax += "0";
                }
            }
        }

        // Check that 'Tip' field is of correct format.
        mTip = et_tip.getText().toString();
        if (mTip.matches("")) {
            // User didn't specify a Tip.
            mTip = "0.00";
        } else {
            if (mTip.indexOf('.') < 0) {
                // User didn't add decimal values.
                mTip += ".00";
            } else {
                int decimalsAfter = mTip.substring(mTip.indexOf(".") + 1).length();
                if (decimalsAfter == 1) {
                    // User did add decimal but only to the tens place.
                    mTip += "0";
                }
            }
        }

		// Retrieve values from EditText fields.
        mInvoice = et_invoice.getText().toString();
        mDesc    = et_desc.getText().toString();
        mRefnum  = et_refnum.getText().toString();
    }

    /**
     * Prepare trans info for bundling.
     */
    private void buildTransInfoMap() {
        transInfo = new HashMap<>();

        transInfo.put("conn_type", mSelectedConn);
        transInfo.put("sale_type", mSelectedSale);
        transInfo.put(UEMConstants.KEY_AMOUNT, mAmount);
        transInfo.put(UEMConstants.KEY_TAX, mTax);
        transInfo.put(UEMConstants.KEY_TIP, mTip);
        transInfo.put(UEMConstants.KEY_INVOICE, mInvoice);
        transInfo.put("description", mDesc);
        transInfo.put(UEMConstants.KEY_COMMAND, mSelectedSale);
        if ( mSelectedSale.equals("void:release") || mSelectedSale.equals("capture") ) {
            transInfo.put(UEMConstants.KEY_REFNUM, mRefnum);
        }
    }

    /**
     * Adds the Tax and Tip to Amount and returns correctly formatted String amount.
     *
     * @param amt Amount
     * @param tax Tax
     * @param tip Tip
     * @return Amount + Tax + Tip in "#.00" format
     */
    private String aggregateTotal(String amt, String tax, String tip) {
        double am, tx, tp;
        am = Double.parseDouble(amt);
        tx = Double.parseDouble(tax);
        tp = Double.parseDouble(tip);

        am = am + tx + tp;

        DecimalFormat df = new DecimalFormat("#.00");

        return df.format(am);
    }
}
