package com.usaepaydemo;


import android.content.Intent;
import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;

import com.usaepay.middleware.struct.UEMTransactionResult;

import java.util.Set;

@SuppressWarnings("unchecked")
public class TransFinishedActivity extends AppCompatActivity {

    private final String TAG = TransFinishedActivity.class.getSimpleName();

    private Button btn_close;
    private TextView tv_trans_results;
	private TextView tv_tran_result;
    UEMTransactionResult transResults;

    @Override
    protected void onCreate(Bundle savedState) {
        super.onCreate(savedState);
        setContentView(R.layout.activity_trans_finished);

        tv_trans_results = (TextView) findViewById(R.id.transDetails);
		tv_tran_result   = (TextView) findViewById(R.id.tran_result);
        Bundle bundleFromTrans = getIntent().getExtras();

        unbundleTransResult(bundleFromTrans);
        displayTransResults();
        setCloseBtnListener();
    }

    /**
     * Unbundles transaction results for use in this Activity.
     */
    private void unbundleTransResult(Bundle b) {
        transResults = b.getParcelable("TransResults");
    }

    /**
     * Sets a listener for the 'Close' button.
     */
    private void setCloseBtnListener() {
        btn_close = (Button) findViewById(R.id.trans_fin_close_btn);
        btn_close.setOnClickListener(new BtnCloseListener());
    }

    /**
     * Displays data from transaction onto this Activity's UI log.
     */
    private void displayTransResults() {
        String results = "";

        Set keySet;

        // ERROR
        if (transResults.getError() != null) {
            results += "ERROR\n";
            results += transResults.getError().text + "\n";
            results += "\n";
        }

        // RECEIPT DATA
        if (transResults.getReceiptData() != null) {

			if (transResults.getReceiptData().containsKey("transResult")) {
				tv_tran_result.setText(transResults.getReceiptData().get("transResult").toString());
			}

            keySet = transResults.getReceiptData().keySet();
            results += "RECEIPT DATA\n";
            for (Object key : keySet) {
                results += key + ": " + transResults.getReceiptData().get(key) + "\n";
            }

            results += "\n";
        }

        // TRANSACTION DATA
        if (transResults.getTransData() != null) {
            keySet = transResults.getTransData().keySet();
            results += "TRANSACTION DATA\n";
            for (Object key : keySet) {
                results += key + ": " + transResults.getTransData().get(key) + "\n";
            }

            results += "\n";
        }

        // GATEWAY TRANSACTION RESULTS
        if (transResults.getGatewayTransactionResults() != null) {
            keySet = transResults.getGatewayTransactionResults().keySet();
            results += "GATEWAY RESULTS\n";
            for (Object key : keySet) {
                results += key + ": " + transResults.getGatewayTransactionResults().get(key) + "\n";
            }

            results += "\n";
        }

        // CVM RESULT
        if (transResults.getCvmResult() != null) {
            results += "CVM RESULT\n";
            results += transResults.getCvmResult().toString() + "\n";
            results += "\n";
        }

        if (transResults.getTenderType() != null) {
            results += "TENDER TYPE\n";
            results += transResults.getTenderType().toString() + "\n";
            results += "\n";
        }

        // DATA SOURCE
        if (transResults.getDataSource() != null) {
            results += "DATA SOURCE\n";
            results += transResults.getDataSource() + "\n";
            results += "\n";
        }

        // ICC DATA
        if (transResults.getICCData() != null) {
            keySet = transResults.getICCData().keySet();
            results += "ICC Data\n";
            for (Object key : keySet) {
                results += key + ": " +  transResults.getICCData().get(key) + "\n";
            }

            results += "\n";
        }

        // RAW GATEWAY RESPONSE
        if (transResults.getRawGatewayResponse() != null) {
            results += "RAW GATEWAY RESPONSE\n";
            results += transResults.getRawGatewayResponse() + "\n";
            results += "\n";
        }

        // TRANSACTION RESPONSE CODE
        if (transResults.getTransResponseCode() != null) {
            results += "TRANSACTION RESPONSE CODE\n";
            results += transResults.getTransData() + "\n";
            results += "\n";
        }

        tv_trans_results.setText(results);
        Log.d(TAG, results);
    }

    /**
     * BtnCloseListener subclass
     *
     * Implements the onClick() method that sends user to MainActivity.
     */
    private class BtnCloseListener implements Button.OnClickListener {

        @Override
        public void onClick(View view) {

            // Go back to MainActivity and clear Activity stack.
            Intent intent = new Intent(TransFinishedActivity.this, MainActivity.class);
            intent.setFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP);
            startActivity(intent);
        }

    }



}
